/*!
 * Bootstrap v5.3.2 (https://getbootstrap.com/)
 * Copyright 2011-2023 The Bootstrap Authors
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 */
.unicom-bootstrap-scope {
  --bs-blue: #0d6efd;
  --bs-indigo: #6610f2;
  --bs-purple: #6f42c1;
  --bs-pink: #d63384;
  --bs-red: #dc3545;
  --bs-orange: #fd7e14;
  --bs-yellow: #ffc107;
  --bs-green: #198754;
  --bs-teal: #20c997;
  --bs-cyan: #0dcaf0;
  --bs-black: #000;
  --bs-white: #fff;
  --bs-gray: #6c757d;
  --bs-gray-dark: #343a40;
  --bs-gray-100: #f8f9fa;
  --bs-gray-200: #e9ecef;
  --bs-gray-300: #dee2e6;
  --bs-gray-400: #ced4da;
  --bs-gray-500: #adb5bd;
  --bs-gray-600: #6c757d;
  --bs-gray-700: #495057;
  --bs-gray-800: #343a40;
  --bs-gray-900: #212529;
  --bs-primary: #0d6efd;
  --bs-secondary: #6c757d;
  --bs-success: #198754;
  --bs-info: #0dcaf0;
  --bs-warning: #ffc107;
  --bs-danger: #dc3545;
  --bs-light: #f8f9fa;
  --bs-dark: #212529;
  --bs-primary-rgb: 13, 110, 253;
  --bs-secondary-rgb: 108, 117, 125;
  --bs-success-rgb: 25, 135, 84;
  --bs-info-rgb: 13, 202, 240;
  --bs-warning-rgb: 255, 193, 7;
  --bs-danger-rgb: 220, 53, 69;
  --bs-light-rgb: 248, 249, 250;
  --bs-dark-rgb: 33, 37, 41;
  --bs-primary-text-emphasis: #052c65;
  --bs-secondary-text-emphasis: #2b2f32;
  --bs-success-text-emphasis: #0a3622;
  --bs-info-text-emphasis: #055160;
  --bs-warning-text-emphasis: #664d03;
  --bs-danger-text-emphasis: #58151c;
  --bs-light-text-emphasis: #495057;
  --bs-dark-text-emphasis: #495057;
  --bs-primary-bg-subtle: #cfe2ff;
  --bs-secondary-bg-subtle: #e2e3e5;
  --bs-success-bg-subtle: #d1e7dd;
  --bs-info-bg-subtle: #cff4fc;
  --bs-warning-bg-subtle: #fff3cd;
  --bs-danger-bg-subtle: #f8d7da;
  --bs-light-bg-subtle: #fcfcfd;
  --bs-dark-bg-subtle: #ced4da;
  --bs-primary-border-subtle: #9ec5fe;
  --bs-secondary-border-subtle: #c4c8cb;
  --bs-success-border-subtle: #a3cfbb;
  --bs-info-border-subtle: #9eeaf9;
  --bs-warning-border-subtle: #ffe69c;
  --bs-danger-border-subtle: #f1aeb5;
  --bs-light-border-subtle: #e9ecef;
  --bs-dark-border-subtle: #adb5bd;
  --bs-white-rgb: 255, 255, 255;
  --bs-black-rgb: 0, 0, 0;
  --bs-font-sans-serif: system-ui, -apple-system, "Segoe UI", Roboto, "Helvetica Neue", "Noto Sans", "Liberation Sans", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  --bs-font-monospace: SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
  --bs-gradient: linear-gradient(180deg, rgba(255, 255, 255, 0.15), rgba(255, 255, 255, 0));
  --bs-body-font-family: var(--bs-font-sans-serif);
  --bs-body-font-size: 1rem;
  --bs-body-font-weight: 400;
  --bs-body-line-height: 1.5;
  --bs-body-color: #212529;
  --bs-body-color-rgb: 33, 37, 41;
  --bs-body-bg: #fff;
  --bs-body-bg-rgb: 255, 255, 255;
  --bs-emphasis-color: #000;
  --bs-emphasis-color-rgb: 0, 0, 0;
  --bs-secondary-color: rgba(33, 37, 41, 0.75);
  --bs-secondary-color-rgb: 33, 37, 41;
  --bs-secondary-bg: #e9ecef;
  --bs-secondary-bg-rgb: 233, 236, 239;
  --bs-tertiary-color: rgba(33, 37, 41, 0.5);
  --bs-tertiary-color-rgb: 33, 37, 41;
  --bs-tertiary-bg: #f8f9fa;
  --bs-tertiary-bg-rgb: 248, 249, 250;
  --bs-heading-color: inherit;
  --bs-link-color: #0d6efd;
  --bs-link-color-rgb: 13, 110, 253;
  --bs-link-decoration: underline;
  --bs-link-hover-color: #0a58ca;
  --bs-link-hover-color-rgb: 10, 88, 202;
  --bs-code-color: #d63384;
  --bs-highlight-color: #212529;
  --bs-highlight-bg: #fff3cd;
  --bs-border-width: 1px;
  --bs-border-style: solid;
  --bs-border-color: #dee2e6;
  --bs-border-color-translucent: rgba(0, 0, 0, 0.175);
  --bs-border-radius: 0.375rem;
  --bs-border-radius-sm: 0.25rem;
  --bs-border-radius-lg: 0.5rem;
  --bs-border-radius-xl: 1rem;
  --bs-border-radius-xxl: 2rem;
  --bs-border-radius-2xl: var(--bs-border-radius-xxl);
  --bs-border-radius-pill: 50rem;
  --bs-box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
  --bs-box-shadow-sm: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
  --bs-box-shadow-lg: 0 1rem 3rem rgba(0, 0, 0, 0.175);
  --bs-box-shadow-inset: inset 0 1px 2px rgba(0, 0, 0, 0.075);
  --bs-focus-ring-width: 0.25rem;
  --bs-focus-ring-opacity: 0.25;
  --bs-focus-ring-color: rgba(13, 110, 253, 0.25);
  --bs-form-valid-color: #198754;
  --bs-form-valid-border-color: #198754;
  --bs-form-invalid-color: #dc3545;
  --bs-form-invalid-border-color: #dc3545;
  color: var(--bs-body-color);
  background-color: var(--bs-body-bg);
}
.unicom-bootstrap-scope *,
.unicom-bootstrap-scope *::before,
.unicom-bootstrap-scope *::after {
  box-sizing: border-box;
}
.unicom-bootstrap-scope h1, .unicom-bootstrap-scope .h1,
.unicom-bootstrap-scope h2, .unicom-bootstrap-scope .h2,
.unicom-bootstrap-scope h3, .unicom-bootstrap-scope .h3,
.unicom-bootstrap-scope h4, .unicom-bootstrap-scope .h4,
.unicom-bootstrap-scope h5, .unicom-bootstrap-scope .h5,
.unicom-bootstrap-scope h6, .unicom-bootstrap-scope .h6 {
  margin-top: 0;
  margin-bottom: 0.5rem;
  font-weight: 500;
  line-height: 1.2;
  color: var(--bs-heading-color);
}
.unicom-bootstrap-scope h1, .unicom-bootstrap-scope .h1 {
  font-size: calc(1.375rem + 1.5vw);
}
@media (min-width: 1200px) {
  .unicom-bootstrap-scope h1, .unicom-bootstrap-scope .h1 {
    font-size: 2.5rem;
  }
}
.unicom-bootstrap-scope h2, .unicom-bootstrap-scope .h2 {
  font-size: calc(1.325rem + 0.9vw);
}
@media (min-width: 1200px) {
  .unicom-bootstrap-scope h2, .unicom-bootstrap-scope .h2 {
    font-size: 2rem;
  }
}
.unicom-bootstrap-scope h3, .unicom-bootstrap-scope .h3 {
  font-size: calc(1.3rem + 0.6vw);
}
@media (min-width: 1200px) {
  .unicom-bootstrap-scope h3, .unicom-bootstrap-scope .h3 {
    font-size: 1.75rem;
  }
}
.unicom-bootstrap-scope h4, .unicom-bootstrap-scope .h4 {
  font-size: calc(1.275rem + 0.3vw);
}
@media (min-width: 1200px) {
  .unicom-bootstrap-scope h4, .unicom-bootstrap-scope .h4 {
    font-size: 1.5rem;
  }
}
.unicom-bootstrap-scope h5, .unicom-bootstrap-scope .h5 {
  font-size: 1.25rem;
}
.unicom-bootstrap-scope h6, .unicom-bootstrap-scope .h6 {
  font-size: 1rem;
}
.unicom-bootstrap-scope p {
  margin-top: 0;
  margin-bottom: 1rem;
}
.unicom-bootstrap-scope a {
  color: var(--bs-link-color);
  text-decoration: var(--bs-link-decoration);
}
.unicom-bootstrap-scope a:hover {
  color: var(--bs-link-hover-color);
}
.unicom-bootstrap-scope button:focus {
  outline: 1px dotted;
  outline: 5px auto -webkit-focus-ring-color;
}
.unicom-bootstrap-scope .modal {
  --bs-modal-zindex: 1055;
  --bs-modal-width: 500px;
  --bs-modal-padding: 1rem;
  --bs-modal-margin: 0.5rem;
  --bs-modal-color: ;
  --bs-modal-bg: var(--bs-body-bg);
  --bs-modal-border-color: var(--bs-border-color-translucent);
  --bs-modal-border-width: var(--bs-border-width);
  --bs-modal-border-radius: var(--bs-border-radius-lg);
  --bs-modal-box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
  --bs-modal-inner-border-radius: calc(0.5rem - 1px);
  --bs-modal-header-padding-x: 1rem;
  --bs-modal-header-padding-y: 1rem;
  --bs-modal-header-padding: 1rem 1rem;
  --bs-modal-header-border-color: var(--bs-border-color);
  --bs-modal-header-border-width: var(--bs-border-width);
  --bs-modal-title-line-height: 1.5;
  --bs-modal-footer-gap: 0.5rem;
  --bs-modal-footer-bg: ;
  --bs-modal-footer-border-color: var(--bs-border-color);
  --bs-modal-footer-border-width: var(--bs-border-width);
  position: fixed;
  top: 0;
  left: 0;
  z-index: var(--bs-modal-zindex);
  display: none;
  width: 100%;
  height: 100%;
  overflow-x: hidden;
  overflow-y: auto;
  outline: 0;
}
.unicom-bootstrap-scope .modal-dialog {
  position: relative;
  width: auto;
  margin: var(--bs-modal-margin);
  pointer-events: none;
}
.unicom-bootstrap-scope .modal.fade .modal-dialog {
  transition: transform 0.3s ease-out;
  transform: translate(0, -50px);
}
@media (prefers-reduced-motion: reduce) {
  .unicom-bootstrap-scope .modal.fade .modal-dialog {
    transition: none;
  }
}
.unicom-bootstrap-scope .modal.show .modal-dialog {
  transform: none;
}
.unicom-bootstrap-scope .modal.modal-static .modal-dialog {
  transform: scale(1.02);
}
.unicom-bootstrap-scope .modal-dialog-scrollable {
  height: calc(100% - var(--bs-modal-margin) * 2);
}
.unicom-bootstrap-scope .modal-dialog-scrollable .modal-content {
  max-height: 100%;
  overflow: hidden;
}
.unicom-bootstrap-scope .modal-dialog-scrollable .modal-body {
  overflow-y: auto;
}
.unicom-bootstrap-scope .modal-dialog-centered {
  display: flex;
  align-items: center;
  min-height: calc(100% - var(--bs-modal-margin) * 2);
}
.unicom-bootstrap-scope .modal-content {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
  color: var(--bs-modal-color);
  pointer-events: auto;
  background-color: var(--bs-modal-bg);
  background-clip: padding-box;
  border: var(--bs-modal-border-width) solid var(--bs-modal-border-color);
  border-radius: var(--bs-modal-border-radius);
  outline: 0;
}
.unicom-bootstrap-scope .modal-backdrop {
  --bs-backdrop-zindex: 1050;
  --bs-backdrop-bg: #000;
  --bs-backdrop-opacity: 0.5;
  position: fixed;
  top: 0;
  left: 0;
  z-index: var(--bs-backdrop-zindex);
  width: 100vw;
  height: 100vh;
  background-color: var(--bs-backdrop-bg);
}
.unicom-bootstrap-scope .modal-backdrop.fade {
  opacity: 0;
}
.unicom-bootstrap-scope .modal-backdrop.show {
  opacity: var(--bs-backdrop-opacity);
}
.unicom-bootstrap-scope .modal-header {
  display: flex;
  flex-shrink: 0;
  align-items: center;
  justify-content: space-between;
  padding: var(--bs-modal-header-padding);
  border-bottom: var(--bs-modal-header-border-width) solid var(--bs-modal-header-border-color);
  border-top-left-radius: var(--bs-modal-inner-border-radius);
  border-top-right-radius: var(--bs-modal-inner-border-radius);
}
.unicom-bootstrap-scope .modal-header .btn-close {
  padding: 0.5rem 0.5rem;
  margin: -0.5rem -0.5rem -0.5rem auto;
}
.unicom-bootstrap-scope .modal-title {
  margin-bottom: 0;
  line-height: var(--bs-modal-title-line-height);
}
.unicom-bootstrap-scope .modal-body {
  position: relative;
  flex: 1 1 auto;
  padding: var(--bs-modal-padding);
}
.unicom-bootstrap-scope .modal-footer {
  display: flex;
  flex-shrink: 0;
  flex-wrap: wrap;
  align-items: center;
  justify-content: flex-end;
  padding: calc(var(--bs-modal-padding) - var(--bs-modal-footer-gap) * 0.5);
  background-color: var(--bs-modal-footer-bg);
  border-top: var(--bs-modal-footer-border-width) solid var(--bs-modal-footer-border-color);
  border-bottom-right-radius: var(--bs-modal-inner-border-radius);
  border-bottom-left-radius: var(--bs-modal-inner-border-radius);
}
.unicom-bootstrap-scope .modal-footer > * {
  margin: calc(var(--bs-modal-footer-gap) * 0.5);
}
@media (min-width: 576px) {
  .unicom-bootstrap-scope .modal {
    --bs-modal-margin: 1.75rem;
    --bs-modal-box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
  }
  .unicom-bootstrap-scope .modal-dialog {
    max-width: var(--bs-modal-width);
    margin-right: auto;
    margin-left: auto;
  }
  .unicom-bootstrap-scope .modal-sm {
    --bs-modal-width: 300px;
  }
}
@media (min-width: 992px) {
  .unicom-bootstrap-scope .modal-lg,
  .unicom-bootstrap-scope .modal-xl {
    --bs-modal-width: 800px;
  }
}
@media (min-width: 1200px) {
  .unicom-bootstrap-scope .modal-xl {
    --bs-modal-width: 1140px;
  }
}
.unicom-bootstrap-scope .modal-fullscreen {
  width: 100vw;
  max-width: none;
  height: 100%;
  margin: 0;
}
.unicom-bootstrap-scope .modal-fullscreen .modal-content {
  height: 100%;
  border: 0;
  border-radius: 0;
}
.unicom-bootstrap-scope .modal-fullscreen .modal-header,
.unicom-bootstrap-scope .modal-fullscreen .modal-footer {
  border-radius: 0;
}
.unicom-bootstrap-scope .modal-fullscreen .modal-body {
  overflow-y: auto;
}
@media (max-width: 575.98px) {
  .unicom-bootstrap-scope .modal-fullscreen-sm-down {
    width: 100vw;
    max-width: none;
    height: 100%;
    margin: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-sm-down .modal-content {
    height: 100%;
    border: 0;
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-sm-down .modal-header,
  .unicom-bootstrap-scope .modal-fullscreen-sm-down .modal-footer {
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-sm-down .modal-body {
    overflow-y: auto;
  }
}
@media (max-width: 767.98px) {
  .unicom-bootstrap-scope .modal-fullscreen-md-down {
    width: 100vw;
    max-width: none;
    height: 100%;
    margin: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-md-down .modal-content {
    height: 100%;
    border: 0;
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-md-down .modal-header,
  .unicom-bootstrap-scope .modal-fullscreen-md-down .modal-footer {
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-md-down .modal-body {
    overflow-y: auto;
  }
}
@media (max-width: 991.98px) {
  .unicom-bootstrap-scope .modal-fullscreen-lg-down {
    width: 100vw;
    max-width: none;
    height: 100%;
    margin: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-lg-down .modal-content {
    height: 100%;
    border: 0;
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-lg-down .modal-header,
  .unicom-bootstrap-scope .modal-fullscreen-lg-down .modal-footer {
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-lg-down .modal-body {
    overflow-y: auto;
  }
}
@media (max-width: 1199.98px) {
  .unicom-bootstrap-scope .modal-fullscreen-xl-down {
    width: 100vw;
    max-width: none;
    height: 100%;
    margin: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xl-down .modal-content {
    height: 100%;
    border: 0;
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xl-down .modal-header,
  .unicom-bootstrap-scope .modal-fullscreen-xl-down .modal-footer {
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xl-down .modal-body {
    overflow-y: auto;
  }
}
@media (max-width: 1399.98px) {
  .unicom-bootstrap-scope .modal-fullscreen-xxl-down {
    width: 100vw;
    max-width: none;
    height: 100%;
    margin: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xxl-down .modal-content {
    height: 100%;
    border: 0;
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xxl-down .modal-header,
  .unicom-bootstrap-scope .modal-fullscreen-xxl-down .modal-footer {
    border-radius: 0;
  }
  .unicom-bootstrap-scope .modal-fullscreen-xxl-down .modal-body {
    overflow-y: auto;
  }
}
/* ... remaining Bootstrap CSS scoped with .unicom-bootstrap-scope ... */
.unicom-bootstrap-scope .btn {
    display: inline-block;
    font-weight: 400;
    line-height: 1.5;
    color: #212529;
    text-align: center;
    text-decoration: none;
    vertical-align: middle;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    user-select: none;
    background-color: transparent;
    border: 1px solid transparent;
    padding: .375rem .75rem;
    font-size: 1rem;
    border-radius: .25rem;
    transition: color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;
}
.unicom-bootstrap-scope .btn-primary {
    color: #fff;
    background-color: #0d6efd;
    border-color: #0d6efd;
}
.unicom-bootstrap-scope .btn-secondary {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d;
}
.unicom-bootstrap-scope .btn-success {
    color: #fff;
    background-color: #198754;
    border-color: #198754;
}
.unicom-bootstrap-scope .form-select {
    display: block;
    width: 100%;
    padding: .375rem 2.25rem .375rem .75rem;
    -moz-padding-start: calc(0.75rem - 3px);
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    color: #212529;
    background-color: #fff;
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23343a40' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e");
    background-repeat: no-repeat;
    background-position: right .75rem center;
    background-size: 16px 12px;
    border: 1px solid #ced4da;
    border-radius: .25rem;
    transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
}
.unicom-bootstrap-scope .btn-close {
  box-sizing: content-box;
  width: 1em;
  height: 1em;
  padding: .25em .25em;
  color: #000;
  background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414z'/%3e%3c/svg%3e") center/1em auto no-repeat;
  border: 0;
  border-radius: .25rem;
  opacity: .5;
}
.unicom-bootstrap-scope .collapse:not(.show) {
    display: none;
}
.unicom-bootstrap-scope .collapsing {
    height: 0;
    overflow: hidden;
    transition: height .35s ease;
}
.unicom-bootstrap-scope .fade {
    transition: opacity .15s linear;
}
.unicom-bootstrap-scope .fade:not(.show) {
    opacity: 0;
}
.unicom-bootstrap-scope .mb-3 {
    margin-bottom: 1rem !important;
}
.unicom-bootstrap-scope .p-0 {
    padding: 0 !important;
}
.unicom-bootstrap-scope .btn-link {
    font-weight: 400;
    color: #0d6efd;
    text-decoration: underline;
}
.unicom-bootstrap-scope .form-label {
    margin-bottom: .5rem;
}

.unicom-bootstrap-scope .btn:disabled,
.unicom-bootstrap-scope .btn.disabled,
.unicom-bootstrap-scope fieldset:disabled .btn {
  pointer-events: none;
  opacity: 0.65;
} 